Contours in OpenCV {#tutorial_py_table_of_contents_contours}
==================

-   @subpage tutorial_py_contours_begin

    Learn to find and draw Contours

-   @subpage tutorial_py_contour_features

    Learn
    to find different features of contours like area, perimeter, bounding rectangle etc.

-   @subpage tutorial_py_contour_properties

    Learn
    to find different properties of contours like Solidity, Mean Intensity etc.

-   @subpage tutorial_py_contours_more_functions

    Learn
    to find convexity defects, pointPolygonTest, match different shapes etc.

-   @subpage tutorial_py_contours_hierarchy

    Learn
    about Contour Hierarchy
